@@ -10,6 +10,7 @@ from typing import (
     Dict,
     ForwardRef,
     Optional,
+    Type,
     TypeVar,
     Union,
     cast,
@@ -60,6 +61,9 @@ class StrawberryAnnotation:
 
         return self.resolve() == other.resolve()
 
+    def __hash__(self) -> int:
+        return hash(self.resolve())
+
     @staticmethod
     def from_annotation(
         annotation: object, namespace: Optional[Dict] = None
@@ -167,7 +171,7 @@ class StrawberryAnnotation:
     def create_type_var(self, evaled_type: TypeVar) -> StrawberryTypeVar:
         return StrawberryTypeVar(evaled_type)
 
-    def create_union(self, evaled_type) -> StrawberryUnion:
+    def create_union(self, evaled_type: Type) -> StrawberryUnion:
         # Prevent import cycles
         from strawberry.union import StrawberryUnion
 
@@ -274,7 +278,7 @@ class StrawberryAnnotation:
         return annotation_origin is typing.Union
 
     @classmethod
-    def _strip_async_type(cls, annotation) -> type:
+    def _strip_async_type(cls, annotation: Type) -> type:
         return annotation.__args__[0]
 
     @classmethod
