@@ -2,6 +2,5 @@ from strawberry.asgi.handlers.graphql_transport_ws_handler import (
     GraphQLTransportWSHandler,
 )
 from strawberry.asgi.handlers.graphql_ws_handler import GraphQLWSHandler
-from strawberry.asgi.handlers.http_handler import HTTPHandler
 
-__all__ = ["GraphQLTransportWSHandler", "GraphQLWSHandler", "HTTPHandler"]
+__all__ = ["GraphQLTransportWSHandler", "GraphQLWSHandler"]
