@@ -1,12 +1,14 @@
 import warnings
 
 from .add_validation_rules import AddValidationRules
-from .base_extension import SchemaExtension
+from .base_extension import LifecycleStep, SchemaExtension
 from .disable_validation import DisableValidation
 from .field_extension import FieldExtension
 from .mask_errors import MaskErrors
+from .max_aliases import MaxAliasesLimiter
+from .max_tokens import MaxTokensLimiter
 from .parser_cache import ParserCache
-from .query_depth_limiter import QueryDepthLimiter
+from .query_depth_limiter import IgnoreContext, QueryDepthLimiter
 from .validation_cache import ValidationCache
 
 
@@ -28,10 +30,14 @@ def __getattr__(name: str):
 __all__ = [
     "FieldExtension",
     "SchemaExtension",
+    "LifecycleStep",
     "AddValidationRules",
     "DisableValidation",
     "ParserCache",
     "QueryDepthLimiter",
+    "IgnoreContext",
     "ValidationCache",
     "MaskErrors",
+    "MaxAliasesLimiter",
+    "MaxTokensLimiter",
 ]
