@@ -2,9 +2,10 @@ from .argument import argument
 from .enum import enum, enum_value
 from .field import field
 from .mutation import mutation
-from .object_type import input, interface, type
+from .object_type import input, interface, interface_object, type
 from .scalar import scalar
 from .schema import Schema
+from .schema_directive import schema_directive
 from .union import union
 
 __all__ = [
@@ -15,8 +16,10 @@ __all__ = [
     "mutation",
     "input",
     "interface",
+    "interface_object",
     "type",
     "scalar",
     "Schema",
+    "schema_directive",
     "union",
 ]
