@@ -15,6 +15,7 @@ from typing import (
     cast,
     overload,
 )
+from typing_extensions import dataclass_transform
 
 from .exceptions import (
     MissingFieldAnnotationError,
@@ -26,7 +27,6 @@ from .types.type_resolver import _get_fields
 from .types.types import TypeDefinition
 from .utils.dataclasses import add_custom_init_fn
 from .utils.str_converters import to_camel_case
-from .utils.typing import __dataclass_transform__
 
 T = TypeVar("T", bound=Type)
 
@@ -124,7 +124,7 @@ def _wrap_dataclass(cls: Type[Any]):
 
 
 def _process_type(
-    cls,
+    cls: Type,
     *,
     name: Optional[str] = None,
     is_input: bool = False,
@@ -177,8 +177,8 @@ def _process_type(
 
 
 @overload
-@__dataclass_transform__(
-    order_default=True, kw_only_default=True, field_descriptors=(field, StrawberryField)
+@dataclass_transform(
+    order_default=True, kw_only_default=True, field_specifiers=(field, StrawberryField)
 )
 def type(
     cls: T,
@@ -194,8 +194,8 @@ def type(
 
 
 @overload
-@__dataclass_transform__(
-    order_default=True, kw_only_default=True, field_descriptors=(field, StrawberryField)
+@dataclass_transform(
+    order_default=True, kw_only_default=True, field_specifiers=(field, StrawberryField)
 )
 def type(
     *,
@@ -223,12 +223,12 @@ def type(
 
     Example usage:
 
-    >>> @strawberry.type:
+    >>> @strawberry.type
     >>> class X:
     >>>     field_abc: str = "ABC"
     """
 
-    def wrap(cls):
+    def wrap(cls: Type):
         if not inspect.isclass(cls):
             if is_input:
                 exc = ObjectIsNotClassError.input
@@ -256,8 +256,8 @@ def type(
 
 
 @overload
-@__dataclass_transform__(
-    order_default=True, kw_only_default=True, field_descriptors=(field, StrawberryField)
+@dataclass_transform(
+    order_default=True, kw_only_default=True, field_specifiers=(field, StrawberryField)
 )
 def input(
     cls: T,
@@ -270,8 +270,8 @@ def input(
 
 
 @overload
-@__dataclass_transform__(
-    order_default=True, kw_only_default=True, field_descriptors=(field, StrawberryField)
+@dataclass_transform(
+    order_default=True, kw_only_default=True, field_specifiers=(field, StrawberryField)
 )
 def input(
     *,
@@ -291,7 +291,7 @@ def input(
 ):
     """Annotates a class as a GraphQL Input type.
     Example usage:
-    >>> @strawberry.input:
+    >>> @strawberry.input
     >>> class X:
     >>>     field_abc: str = "ABC"
     """
@@ -306,8 +306,8 @@ def input(
 
 
 @overload
-@__dataclass_transform__(
-    order_default=True, kw_only_default=True, field_descriptors=(field, StrawberryField)
+@dataclass_transform(
+    order_default=True, kw_only_default=True, field_specifiers=(field, StrawberryField)
 )
 def interface(
     cls: T,
@@ -320,8 +320,8 @@ def interface(
 
 
 @overload
-@__dataclass_transform__(
-    order_default=True, kw_only_default=True, field_descriptors=(field, StrawberryField)
+@dataclass_transform(
+    order_default=True, kw_only_default=True, field_specifiers=(field, StrawberryField)
 )
 def interface(
     *,
@@ -332,8 +332,8 @@ def interface(
     ...
 
 
-@__dataclass_transform__(
-    order_default=True, kw_only_default=True, field_descriptors=(field, StrawberryField)
+@dataclass_transform(
+    order_default=True, kw_only_default=True, field_specifiers=(field, StrawberryField)
 )
 def interface(
     cls: Optional[T] = None,
@@ -344,7 +344,7 @@ def interface(
 ):
     """Annotates a class as a GraphQL Interface.
     Example usage:
-    >>> @strawberry.interface:
+    >>> @strawberry.interface
     >>> class X:
     >>>     field_abc: str
     """
@@ -358,7 +358,7 @@ def interface(
     )
 
 
-def asdict(obj: object) -> Dict[str, object]:
+def asdict(obj: Any) -> Dict[str, object]:
     """Convert a strawberry object into a dictionary.
     This wraps the dataclasses.asdict function to strawberry.
 
@@ -370,7 +370,7 @@ def asdict(obj: object) -> Dict[str, object]:
     >>> # should be {"name": "Lorem", "age": 25}
     >>> user_dict = strawberry.asdict(User(name="Lorem", age=25))
     """
-    return dataclasses.asdict(obj)  # type: ignore
+    return dataclasses.asdict(obj)
 
 
 __all__ = [
