@@ -14,7 +14,7 @@ class BasePermission:
     message: Optional[str] = None
 
     def has_permission(
-        self, source: Any, info: Info, **kwargs
+        self, source: Any, info: Info, **kwargs: Any
     ) -> Union[bool, Awaitable[bool]]:
         raise NotImplementedError(
             "Permission classes should override has_permission method"
