@@ -10,6 +10,7 @@ from typing import (
     Optional,
     Set,
     Tuple,
+    Type,
     TypeVar,
     Union,
     cast,
@@ -225,7 +226,7 @@ def print_args(
     )
 
 
-def print_fields(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+def print_fields(type_: Type, schema: BaseSchema, *, extras: PrintExtras) -> str:
     from strawberry.schema.schema_converter import GraphQLCoreConverter
 
     fields = []
@@ -276,7 +277,7 @@ def print_scalar(
 def print_enum_value(
     name: str,
     value: GraphQLEnumValue,
-    first_in_block,
+    first_in_block: bool,
     *,
     schema: BaseSchema,
     extras: PrintExtras,
@@ -320,7 +321,7 @@ def print_enum(
     )
 
 
-def print_extends(type_, schema: BaseSchema) -> str:
+def print_extends(type_: Type, schema: BaseSchema) -> str:
     from strawberry.schema.schema_converter import GraphQLCoreConverter
 
     strawberry_type = type_.extensions and type_.extensions.get(
@@ -333,7 +334,9 @@ def print_extends(type_, schema: BaseSchema) -> str:
     return ""
 
 
-def print_type_directives(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+def print_type_directives(
+    type_: Type, schema: BaseSchema, *, extras: PrintExtras
+) -> str:
     from strawberry.schema.schema_converter import GraphQLCoreConverter
 
     strawberry_type = type_.extensions and type_.extensions.get(
@@ -362,7 +365,7 @@ def print_type_directives(type_, schema: BaseSchema, *, extras: PrintExtras) ->
     )
 
 
-def _print_object(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+def _print_object(type_: Any, schema: BaseSchema, *, extras: PrintExtras) -> str:
     return (
         print_description(type_)
         + print_extends(type_, schema)
@@ -373,7 +376,7 @@ def _print_object(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
     )
 
 
-def _print_interface(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+def _print_interface(type_: Any, schema: BaseSchema, *, extras: PrintExtras) -> str:
     return (
         print_description(type_)
         + print_extends(type_, schema)
@@ -392,7 +395,7 @@ def print_input_value(name: str, arg: GraphQLArgument) -> str:
     return arg_decl + print_deprecated(arg.deprecation_reason)
 
 
-def _print_input_object(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+def _print_input_object(type_: Any, schema: BaseSchema, *, extras: PrintExtras) -> str:
     from strawberry.schema.schema_converter import GraphQLCoreConverter
 
     fields = []
@@ -436,7 +439,7 @@ def print_union(
     )
 
 
-def _print_type(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+def _print_type(type_: Any, schema: BaseSchema, *, extras: PrintExtras) -> str:
     # prevents us from trying to print a scalar as an input type
     if is_scalar_type(type_):
         return print_scalar(type_, schema=schema, extras=extras)
