@@ -60,7 +60,9 @@ class NameConverter:
         return self.get_graphql_name(argument)
 
     def from_object(self, object_type: TypeDefinition) -> str:
-        if object_type.concrete_of:
+        # if concrete_of is not generic, than this is a subclass of an already
+        # especialized type.
+        if object_type.concrete_of and object_type.concrete_of.is_generic:
             return self.from_generic(
                 object_type, list(object_type.type_var_map.values())
             )
