@@ -13,6 +13,7 @@ if TYPE_CHECKING:
     from graphql.language import FieldNode
     from graphql.pyutils.path import Path
 
+    from strawberry.arguments import StrawberryArgument
     from strawberry.field import StrawberryField
     from strawberry.schema import Schema
     from strawberry.type import StrawberryType
@@ -82,3 +83,13 @@ class Info(Generic[ContextType, RootValueType]):
         return self._raw_info.path
 
     # TODO: parent_type as strawberry types
+
+    # Helper functions
+    def get_argument_definition(self, name: str) -> Optional[StrawberryArgument]:
+        """
+        Get the StrawberryArgument definition for the current field by name.
+        """
+        try:
+            return next(arg for arg in self._field.arguments if arg.python_name == name)
+        except StopIteration:
+            return None
